unit uServerContainer;

interface

uses System.SysUtils, System.Classes, Dialogs,
  Data.DBXTransport,
  Datasnap.DSTCPServerTransport,
  Datasnap.DSHTTPCommon, Datasnap.DSHTTP,
  Datasnap.DSServer, Datasnap.DSCommonServer,
  Datasnap.DSAuth, IndyPeerImpl, DbxSocketChannelNative, DbxCompressionFilter,
  IPPeerServer;

type
  TServerContainer = class(TDataModule)
    DSServer: TDSServer;
    DSTCPServerTransport: TDSTCPServerTransport;
    DSHTTPService: TDSHTTPService;
    DSAuthenticationManager: TDSAuthenticationManager;
    DSServerClass: TDSServerClass;
    procedure DSServerClassGetClass(DSServerClass: TDSServerClass;
      var PersistentClass: TPersistentClass);
    procedure DSAuthenticationManagerUserAuthenticate(Sender: TObject;
      const Protocol, Context, User, Password: string; var valid: Boolean;
      UserRoles: TStrings);
    procedure DSServerConnect(DSConnectEventObject: TDSConnectEventObject);
    procedure DSServerDisconnect(DSConnectEventObject: TDSConnectEventObject);
  private
    { Private declarations }
  public
    function AddFilter(ServerTransport: TDSServerTransport; Filter: String; Key: String = ''): boolean;
    procedure RemoveFilter(ServerTransport: TDSServerTransport; Filter: String);
  end;

var
  ServerContainer: TServerContainer;

implementation

uses Winapi.Windows, uServerMethods, uSerevr;

{$R *.dfm}

procedure TServerContainer.DSServerClassGetClass(
  DSServerClass: TDSServerClass; var PersistentClass: TPersistentClass);
begin
  PersistentClass := uServerMethods.TServerMethods;
end;


procedure TServerContainer.DSServerConnect(DSConnectEventObject: TDSConnectEventObject);
var
  ci: TDBXClientInfo;
begin
  ci := DSConnectEventObject.ChannelInfo.ClientInfo;
  fMainServer.mStatus.Lines.Add(Format('Client %s Connected IP: %s, Port: %s', [ci.Protocol, ci.IpAddress, ci.ClientPort]));
end;

procedure TServerContainer.DSServerDisconnect(DSConnectEventObject: TDSConnectEventObject);
var
  ci: TDBXClientInfo;
begin
  ci := DSConnectEventObject.ChannelInfo.ClientInfo;
  fMainServer.mStatus.Lines.Add(Format('Client %s Disconnected IP: %s, Port: %s', [ci.Protocol, ci.IpAddress, ci.ClientPort]));
end;

function TServerContainer.AddFilter(ServerTransport: TDSServerTransport;
  Filter: String; Key: String = ''): boolean;
var
  i: integer;
begin
  Result := False;
  for i := 0 to ServerTransport.Filters.Count - 1 do
    if ServerTransport.Filters.FilterIdList[i] = Filter then
      exit;
  if Filter = 'PC1' then
  begin
    i := ServerTransport.Filters.AddFilter(TTransportCypherFilter.Create);
    ServerTransport.Filters.GetFilter(i).SetParameterValue('Key', Key);
  end
  else if Filter = 'RSA' then
  begin
    i := ServerTransport.Filters.AddFilter(TTransportCypherFilter.Create);
    ServerTransport.Filters.GetFilter(i).SetParameterValue('UseGlobalKey', 'true');
    ServerTransport.Filters.GetFilter(i).SetParameterValue('KeyLength', '1024');
    ServerTransport.Filters.GetFilter(i).SetParameterValue('KeyExponent','3');
  end
  else if Filter = 'ZLibCompression' then
  begin
    i := ServerTransport.Filters.AddFilter(TTransportCompressionFilter.Create);
    ServerTransport.Filters.GetFilter(i).SetParameterValue('CompressMoreThan','1024');
  end;
  Result := True;
end;

procedure TServerContainer.RemoveFilter(ServerTransport: TDSServerTransport;
  Filter: String);
var
  i: integer;
begin
  for i := 0 to ServerTransport.Filters.Count - 1 do
    if ServerTransport.Filters.FilterIdList[i] = Filter then
    begin
      ServerTransport.Filters.RemoveFilter(i);
      exit;
    end;
end;

procedure TServerContainer.DSAuthenticationManagerUserAuthenticate(
  Sender: TObject; const Protocol, Context, User, Password: string;
  var valid: Boolean; UserRoles: TStrings);
begin
  valid := ServerMethods.CheckUser(User, Password);
end;

end.

